Commit: 4226ee0b71fec6f08897dacf3d6632526618acca
Author: Campbell Barton
Date:   Tue Jan 15 23:15:58 2019 +1100
Branches: master
https://developer.blender.org/rB4226ee0b71fec6f08897dacf3d6632526618acca

Cleanup: comment line length (blenlib)

Prevents clang-format wrapping text before comments.

===================================================================

M       source/blender/blenlib/BLI_astar.h
M       source/blender/blenlib/BLI_ghash.h
M       source/blender/blenlib/BLI_kdopbvh.h
M       source/blender/blenlib/BLI_noise.h
M       source/blender/blenlib/BLI_scanfill.h
M       source/blender/blenlib/BLI_string_utf8.h
M       source/blender/blenlib/intern/BLI_dial_2d.c
M       source/blender/blenlib/intern/BLI_filelist.c
M       source/blender/blenlib/intern/BLI_ghash.c
M       source/blender/blenlib/intern/BLI_kdopbvh.c
M       source/blender/blenlib/intern/DLRB_tree.c
M       source/blender/blenlib/intern/array_store.c
M       source/blender/blenlib/intern/astar.c
M       source/blender/blenlib/intern/expr_pylike_eval.c
M       source/blender/blenlib/intern/freetypefont.c
M       source/blender/blenlib/intern/hash_md5.c
M       source/blender/blenlib/intern/math_color.c
M       source/blender/blenlib/intern/math_geom.c
M       source/blender/blenlib/intern/math_interp.c
M       source/blender/blenlib/intern/math_matrix.c
M       source/blender/blenlib/intern/math_rotation.c
M       source/blender/blenlib/intern/noise.c
M       source/blender/blenlib/intern/path_util.c
M       source/blender/blenlib/intern/polyfill_2d.c
M       source/blender/blenlib/intern/polyfill_2d_beautify.c
M       source/blender/blenlib/intern/rct.c
M       source/blender/blenlib/intern/scanfill.c
M       source/blender/blenlib/intern/scanfill_utils.c
M       source/blender/blenlib/intern/string.c
M       source/blender/blenlib/intern/string_utf8.c
M       source/blender/blenlib/intern/task.c
M       source/blender/blenlib/intern/timecode.c
M       source/blender/blenlib/intern/voxel.c

===================================================================

diff --git a/source/blender/blenlib/BLI_astar.h 
b/source/blender/blenlib/BLI_astar.h
index 99e0dcd1a27..6edb97c1eca 100644
--- a/source/blender/blenlib/BLI_astar.h
+++ b/source/blender/blenlib/BLI_astar.h
@@ -54,9 +54,13 @@ typedef struct BLI_AStarGNode {
 
 typedef struct BLI_AStarSolution {
        /* Final 'most useful' data. */
-       int steps;  /* Number of steps (i.e. walked links) in path (nodes num, 
including start and end, is steps + 1). */
-       int *prev_nodes;  /* Store the path, in reversed order (from 
destination to source node), as indices. */
-       BLI_AStarGNLink **prev_links;  /* Indices are nodes' ones, as 
prev_nodes, but they map to relevant link. */
+       /** Number of steps (i.e. walked links) in path
+        * (nodes num, including start and end, is steps + 1). */
+       int steps;
+       /** Store the path, in reversed order (from destination to source 
node), as indices. */
+       int *prev_nodes;
+       /** Indices are nodes' ones, as prev_nodes, but they map to relevant 
link. */
+       BLI_AStarGNLink **prev_links;
 
        void *custom_data;
 
diff --git a/source/blender/blenlib/BLI_ghash.h 
b/source/blender/blenlib/BLI_ghash.h
index 7003eb039dd..35547115726 100644
--- a/source/blender/blenlib/BLI_ghash.h
+++ b/source/blender/blenlib/BLI_ghash.h
@@ -77,7 +77,8 @@ enum {
 
 #ifdef GHASH_INTERNAL_API
        /* Internal usage only */
-       GHASH_FLAG_IS_GSET      = (1 << 16),  /* Whether the GHash is actually 
used as GSet (no value storage). */
+       /* Whether the GHash is actually used as GSet (no value storage). */
+       GHASH_FLAG_IS_GSET      = (1 << 16),
 #endif
 };
 
diff --git a/source/blender/blenlib/BLI_kdopbvh.h 
b/source/blender/blenlib/BLI_kdopbvh.h
index d83de68169e..c43b76c3c58 100644
--- a/source/blender/blenlib/BLI_kdopbvh.h
+++ b/source/blender/blenlib/BLI_kdopbvh.h
@@ -151,7 +151,8 @@ void BLI_bvhtree_update_tree(BVHTree *tree);
 
 int BLI_bvhtree_overlap_thread_num(const BVHTree *tree);
 
-/* collision/overlap: check two trees if they overlap, alloc's *overlap with 
length of the int return value */
+/* collision/overlap: check two trees if they overlap,
+ * alloc's *overlap with length of the int return value */
 BVHTreeOverlap *BLI_bvhtree_overlap(
         const BVHTree *tree1, const BVHTree *tree2, unsigned int 
*r_overlap_tot,
         BVHTree_OverlapCallback callback, void *userdata);
@@ -161,7 +162,8 @@ int   BLI_bvhtree_get_tree_type(const BVHTree *tree);
 float BLI_bvhtree_get_epsilon(const BVHTree *tree);
 
 /* find nearest node to the given coordinates
- * (if nearest is given it will only search nodes where square distance is 
smaller than nearest->dist) */
+ * (if nearest is given it will only search nodes where
+ * square distance is smaller than nearest->dist) */
 int BLI_bvhtree_find_nearest_ex(
         BVHTree *tree, const float co[3], BVHTreeNearest *nearest,
         BVHTree_NearestPointCallback callback, void *userdata,
diff --git a/source/blender/blenlib/BLI_noise.h 
b/source/blender/blenlib/BLI_noise.h
index 03f2c588f5e..6749d74009a 100644
--- a/source/blender/blenlib/BLI_noise.h
+++ b/source/blender/blenlib/BLI_noise.h
@@ -42,7 +42,8 @@ float BLI_hnoise(float noisesize, float x, float y, float z);
 float BLI_hnoisep(float noisesize, float x, float y, float z);
 float BLI_turbulence(float noisesize, float x, float y, float z, int nr);
 float BLI_turbulence1(float noisesize, float x, float y, float z, int nr);
-/* newnoise: generic noise & turbulence functions to replace the above 
BLI_hnoise/p & BLI_turbulence/1.
+/* newnoise: generic noise & turbulence functions
+ * to replace the above BLI_hnoise/p & BLI_turbulence/1.
  * This is done so different noise basis functions can be used */
 float BLI_gNoise(float noisesize, float x, float y, float z, int hard, int 
noisebasis);
 float BLI_gTurbulence(float noisesize, float x, float y, float z, int oct, int 
hard, int noisebasis);
diff --git a/source/blender/blenlib/BLI_scanfill.h 
b/source/blender/blenlib/BLI_scanfill.h
index f6b37fa2ec3..eaca79801be 100644
--- a/source/blender/blenlib/BLI_scanfill.h
+++ b/source/blender/blenlib/BLI_scanfill.h
@@ -71,13 +71,19 @@ typedef struct ScanFillVert {
                int                  i;
                unsigned int         u;
        } tmp;
-       float co[3];  /* vertex location */
-       float xy[2];  /* 2D projection of vertex location */
-       unsigned int keyindex; /* index, caller can use how it likes to match 
the scanfill result with own data */
+       /** vertex location */
+       float co[3];
+       /** 2D projection of vertex location */
+       float xy[2];
+       /** index, caller can use how it likes to match the scanfill result 
with own data */
+       unsigned int keyindex;
        unsigned short poly_nr;
-       unsigned char edge_tot;  /* number of edges using this vertex */
-       unsigned int f : 4;  /* vert status */
-       unsigned int user_flag : 4;  /* flag callers can use as they like */
+       /** number of edges using this vertex */
+       unsigned char edge_tot;
+       /** vert status */
+       unsigned int f : 4;
+       /** flag callers can use as they like */
+       unsigned int user_flag : 4;
 } ScanFillVert;
 
 typedef struct ScanFillEdge {
diff --git a/source/blender/blenlib/BLI_string_utf8.h 
b/source/blender/blenlib/BLI_string_utf8.h
index 21542d0d6e1..4617a3abf64 100644
--- a/source/blender/blenlib/BLI_string_utf8.h
+++ b/source/blender/blenlib/BLI_string_utf8.h
@@ -39,7 +39,8 @@ char        *BLI_strncat_utf8(char *__restrict dst, const 
char *__restrict src,
 ptrdiff_t    BLI_utf8_invalid_byte(const char *str, size_t length) 
ATTR_NONNULL();
 int          BLI_utf8_invalid_strip(char *str, size_t length) ATTR_NONNULL();
 
-int          BLI_str_utf8_size(const char *p) ATTR_NONNULL(); /* warning, can 
return -1 on bad chars */
+/* warning, can return -1 on bad chars */
+int          BLI_str_utf8_size(const char *p) ATTR_NONNULL();
 int          BLI_str_utf8_size_safe(const char *p) ATTR_NONNULL();
 /* copied from glib */
 unsigned int BLI_str_utf8_as_unicode(const char *p) ATTR_NONNULL();
@@ -64,7 +65,8 @@ size_t       BLI_strncpy_wchar_from_utf8(wchar_t *__restrict 
dst, const char *__
 /* count columns that character/string occupies, based on wcwidth.c */
 int          BLI_wcwidth(wchar_t ucs);
 int          BLI_wcswidth(const wchar_t *pwcs, size_t n) ATTR_NONNULL();
-int          BLI_str_utf8_char_width(const char *p) ATTR_NONNULL(); /* 
warning, can return -1 on bad chars */
+/* warning, can return -1 on bad chars */
+int          BLI_str_utf8_char_width(const char *p) ATTR_NONNULL();
 int          BLI_str_utf8_char_width_safe(const char *p) ATTR_NONNULL();
 
 size_t       BLI_str_partition_utf8(const char *str, const unsigned int 
delim[], const char **sep, const char **suf) ATTR_NONNULL();
diff --git a/source/blender/blenlib/intern/BLI_filelist.c 
b/source/blender/blenlib/intern/BLI_filelist.c
index 76de52bda66..976a496c45b 100644
--- a/source/blender/blenlib/intern/BLI_filelist.c
+++ b/source/blender/blenlib/intern/BLI_filelist.c
@@ -179,7 +179,8 @@ static void bli_builddir(struct BuildDirCtx *dir_ctx, const 
char *dirname)
                                                file->type = file->s.st_mode;
                                        }
                                        else if 
(FILENAME_IS_CURRPAR(file->relname)) {
-                                               /* Hack around for UNC paths on 
windows - does not support stat on '\\SERVER\foo\..', sigh... */
+                                               /* Hack around for UNC paths on 
windows:
+                                                * does not support stat on 
'\\SERVER\foo\..', sigh... */
                                                file->type |= S_IFDIR;
                                        }
                                        dir_ctx->nrfiles++;
diff --git a/source/blender/blenlib/intern/BLI_ghash.c 
b/source/blender/blenlib/intern/BLI_ghash.c
index 3c5fbf5c6e9..7dac54d69bb 100644
--- a/source/blender/blenlib/intern/BLI_ghash.c
+++ b/source/blender/blenlib/intern/BLI_ghash.c
@@ -242,8 +242,8 @@ static void ghash_buckets_resize(GHash *gh, const uint 
nbuckets)
                                        buckets_new[bucket_index] = e;
                                }
 #else
-                               /* No need to recompute hashes in this case, 
since our mask is just smaller, all items in old bucket i
-                                * will go in same new bucket (i & new_mask)! */
+                               /* No need to recompute hashes in this case, 
since our mask is just smaller,
+                                * all items in old bucket 'i' will go in same 
new bucket (i & new_mask)! */
                                const unsigned bucket_index = 
ghash_bucket_index(gh, i);
                                BLI_assert(!buckets_old[i] || (bucket_index == 
ghash_bucket_index(gh, ghash_entryhash(gh, buckets_old[i]))));
                                Entry *e;
@@ -614,8 +614,9 @@ static Entry *ghash_pop(GHash *gh, GHashIterState *state)
                return NULL;
        }
 
-       /* Note: using first_bucket_index here allows us to avoid potential 
huge number of loops over buckets,
-        *       in case we are popping from a large ghash with few items in 
it... */
+       /* Note: using first_bucket_index here allows us to avoid potential
+        * huge number of loops over buckets,
+        * in case we are popping from a large ghash with few items in it... */
        curr_bucket = ghash_find_next_bucket_index(gh, curr_bucket);
 
        Entry *e = gh->buckets[curr_bucket];
@@ -681,7 +682,8 @@ static GHash *ghash_copy(GHash *gh, GHashKeyCopyFP 
keycopyfp, GHashValCopyFP val
                         * This means entries in buckets in new copy will be in 
reversed order!
                         * This shall not be an issue though, since order 
should never be 

@@ Diff output truncated at 10240 characters. @@

_______________________________________________
Bf-blender-cvs mailing list
[email protected]
https://lists.blender.org/mailman/listinfo/bf-blender-cvs

Reply via email to
diff --git a/source/blender/blenlib/intern/BLI_dial_2d.c 
b/source/blender/blenlib/intern/BLI_dial_2d.c
index 1f4c59ac2fb..eb18b307e3c 100644
--- a/source/blender/blenlib/intern/BLI_dial_2d.c
+++ b/source/blender/blenlib/intern/BLI_dial_2d.c
@@ -66,7 +66,8 @@ float BLI_dial_angle(Dial *dial, const float 
current_position[2])
 
        sub_v2_v2v2(current_direction, current_position, dial->center);
 
-       /* only update when we have enough precision, by having the mouse 
adequately away from center */
+       /* only update when we have enough precision,
+        * by having the mouse adequately away from center */
        if (len_squared_v2(current_direction) > dial->threshold_squared) {
                float angle;
                float cosval, sinval;
@@ -86,7 +87,8 @@ float BLI_dial_angle(Dial *dial, const float 
current_position[2])
                angle = atan2f(sinval, cosval);
 
                /* change of sign, we passed the 180 degree threshold. This 
means we need to add a turn.
-                * to distinguish between transition from 0 to -1 and -PI to 
+PI, use comparison with PI/2 */
+                * to distinguish between transition from 0 to -1 and -PI to 
+PI,
+                * use comparison with PI/2 */
                if ((angle * dial->last_angle < 0.0f) &&
                    (fabsf(dial->last_angle) > (float)M_PI_2))
                {